@@ -223,6 +223,15 @@ The value of the option may be arbitrary, but the default bindings
 expect it to be either B<single>, B<browse>, B<multiple>, 
 B<extended> or B<dragdrop>;  the default value is B<browse>.
 
+=item Name: B<-showcursoralways> => I<boolean>
+
+Starting with version 2.4, Tk::HListbox no longer displays the keyboard 
+cursor (active element) when the HListbox widget does not have the 
+keyboard focus, in order to be consistent with the behaviour of 
+Tk::Listbox.  This option, when set to 1 (or a "true" value) restores 
+the pre-v2.4 behaviour of always showing the keyboard cursor.
+Default I<0> (False).
+
 =item Name:	B<state>
 
 =item Class:	B<State>
@@ -519,15 +528,6 @@ I<Color> specifies the foreground color to use when displaying the
 item while it is selected. It may have any of the forms accepted by
 Tk_GetColor.
 
-=item B<-showcursoralways> I<boolean>
-
-Starting with version 2.4, Tk::HListbox no longer displays the keyboard 
-cursor (active element) when the HListbox widget does not have the 
-keyboard focus, in order to be consistent with the behaviour of 
-Tk::Listbox.  This option, when set to 1 (or a "true" value) restores 
-the pre-v2.4 behaviour of always showing the keyboard cursor.
-Default I<0> (False).
-
 =back
 
 =item I<$listbox>-E<gt>B<nearest>(I<y>)
@@ -1178,7 +1178,7 @@ use Tk;
 use Tk::ItemStyle;
 use base qw(Tk::Derived Tk::HList);
 use vars qw($VERSION @Selection $Prev $tixIndicatorArmed);
-$VERSION = '2.4';
+$VERSION = '2.41';
 
 Tk::Widget->Construct('HListbox');
 
@@ -1533,6 +1533,7 @@ sub selectionClear {
 }
 
 sub anchorSet {  #HList's "anchor" is it's (active) cursor, so we use a "virtual anchor" for ours.
+	my ($w) = shift;
 	return  if ($w->{Configure}{'-state'} =~ /d/o);
 	return  unless (defined($_[1]) && $_[1] =~ /\S/o);
 
@@ -1792,7 +1793,7 @@ sub getLastEntry {
 sub getEntry {    #GIVEN A VALID LISTBOX "INDEX", RETURN THE EQUIVALENT HList "ENTRY" (NUMERIC, BUT NOT ZERO-BASED!):
 	my ($w, $index) = @_;
 
-	return $w->getLastEntry  if ($index =~ /^end/io);
+	return $w->getLastEntry  if (defined($index) && $index =~ /^end/io);
 	$index = $w->index($index);
 	my $next = $w->getFirstEntry;
 	my $next0;
@@ -1831,7 +1832,7 @@ sub indexOf {  #GIVEN A VALID HList "ENTRY", RETURN IT'S RELATIVE (TO ZERO=1ST)
 	return undef;   #ENTRY DOES NOT EXIST!			
 }
 
-sub index {    #GIVEN A VALIE "LISTBOX INDEX", RETURN A ZERO-BASED "INDEX" (CONVERTS STUFF LIKE "@x,y", "end". etc:
+sub index {    #GIVEN A VALUE "LISTBOX INDEX", RETURN A ZERO-BASED "INDEX" (CONVERTS STUFF LIKE "@x,y", "end". etc:
 	my $w = $_[0];
 	if ($_[1] =~ /^\d+$/o) {
 		return $_[1];
